@@ -634,7 +634,9 @@ def parse_emulator(url, d):
         if key not in packages:
             packages[key] = url
         versioned = (key[0], source_properties['pkg.revision'])
-        if versioned not in packages:
+        if versioned in packages:
+            packages[versioned] = sorted([url, packages[key]])[-1]
+        else:
             packages[versioned] = url
 
 
@@ -1033,9 +1035,13 @@ def _generate_package_xml(install_dir, package, url):
 
     """
 
-    if package.split(';')[0] in ('extras', 'platforms', 'sources', 'system-images'):
+    package_base = package.split(';')[0]
+    if package_base in ('extras', 'platforms', 'sources', 'system-images'):
         return
 
+    if package_base == 'emulator':
+        package = 'emulator'
+
     revision = revisions[url]
     template = ('<major>{0}</major>', '<minor>{1}</minor>', '<micro>{2}</micro>')
     r = min(3, len(revision))
